@@ -10,11 +10,17 @@ def helper(x, grams):
 		count = 0
 		s = ""
 		for i in ff:
-			files[x].add(hashlib.md5(i.encode("utf-8")).hexdigest())
+			try:
+				files[x].add(hashlib.md5(i.encode('latin-1')).hexdigest())
+			except:
+				print("error of codec in: ", x)
 			s += i
 			count += 1
 			if count == grams:
-				files[x].add(hashlib.md5(s.encode("utf-8")).hexdigest())
+				try:
+					files[x].add(hashlib.md5(s.encode("utf-8")).hexdigest())
+				except:
+					print("error of codec in: ", x)
 				s = list(s.split("\n")[1:]).reduce(lambda x,y: IF(x=="", x+y,x+"\n"+y ))
 				count-=1
 
